@@ -17,9 +17,9 @@ username = sys.argv[3]
 password = sys.argv[4]
 
 if username:
-    url = 'http://%s:%s@127.0.0.1:9001/RPC2' % (quote(username, safe=''), quote(password, safe=''))
+    url = "http://%s:%s@127.0.0.1:9001/RPC2" % (quote(username, safe=""), quote(password, safe=""))
 else:
-    url = 'http://127.0.0.1:9001/RPC2'
+    url = "http://127.0.0.1:9001/RPC2"
 
 server = ServerProxy(url, verbose=True)
-server.supervisor.sendProcessStdin(proc, 'import sys; print(%s); sys.stdout.flush();\n' % value)
+server.supervisor.sendProcessStdin(proc, "import sys; print(%s); sys.stdout.flush();\n" % value)
