@@ -4,7 +4,6 @@
 
 from __future__ import annotations
 
-import unittest
 from contextlib import contextmanager
 from unittest.mock import patch
 
@@ -148,6 +147,31 @@ class TestKeycloakUserprofile(ModuleTestCase):
                                 "required": {"roles": ["user"]},
                                 "validations": {"length": {"max": 255}, "person_name_prohibited_characters": {}},
                             },
+                            {
+                                "annotations": {},
+                                "displayName": "${testAttr}",
+                                "multivalued": False,
+                                "name": "testAttr",
+                                "permissions": {"edit": ["admin", "user"], "view": ["admin", "user"]},
+                                "required": {"roles": ["user"]},
+                                "validations": {
+                                    "integer": {"min": 0, "max": 255},
+                                    "double": {},
+                                    "iso_date": {},
+                                    "local_date": {},
+                                },
+                            },
+                            {
+                                "annotations": {},
+                                "displayName": "${testAttr2}",
+                                "multivalued": True,
+                                "name": "testAttr2",
+                                "permissions": {"edit": ["admin", "user"], "view": ["admin", "user"]},
+                                "required": {"roles": ["user"]},
+                                "validations": {
+                                    "multivalued": {"min": 0, "max": 5},
+                                },
+                            },
                         ],
                         "groups": [
                             {
@@ -210,6 +234,31 @@ class TestKeycloakUserprofile(ModuleTestCase):
                                     "multivalued": False,
                                     "annotations": {},
                                 },
+                                {
+                                    "annotations": {},
+                                    "displayName": "${testAttr}",
+                                    "multivalued": False,
+                                    "name": "testAttr",
+                                    "permissions": {"edit": ["admin", "user"], "view": ["admin", "user"]},
+                                    "required": {"roles": ["user"]},
+                                    "validations": {
+                                        "integer": {"min": 0, "max": 255},
+                                        "double": {},
+                                        "iso_date": {},
+                                        "local_date": {},
+                                    },
+                                },
+                                {
+                                    "annotations": {},
+                                    "displayName": "${testAttr2}",
+                                    "multivalued": True,
+                                    "name": "testAttr2",
+                                    "permissions": {"edit": ["admin", "user"], "view": ["admin", "user"]},
+                                    "required": {"roles": ["user"]},
+                                    "validations": {
+                                        "multivalued": {"min": 0, "max": 5},
+                                    },
+                                },
                             ],
                             "groups": [
                                 {
@@ -306,6 +355,31 @@ class TestKeycloakUserprofile(ModuleTestCase):
                                 "required": {"roles": ["user"]},
                                 "validations": {"length": {"max": 255}, "person_name_prohibited_characters": {}},
                             },
+                            {
+                                "annotations": {},
+                                "displayName": "${testAttr}",
+                                "multivalued": False,
+                                "name": "testAttr",
+                                "permissions": {"edit": ["admin", "user"], "view": ["admin", "user"]},
+                                "required": {"roles": ["user"]},
+                                "validations": {
+                                    "integer": {"min": 0, "max": 255},
+                                    "double": {},
+                                    "iso_date": {},
+                                    "local_date": {},
+                                },
+                            },
+                            {
+                                "annotations": {},
+                                "displayName": "${testAttr2}",
+                                "multivalued": True,
+                                "name": "testAttr2",
+                                "permissions": {"edit": ["admin", "user"], "view": ["admin", "user"]},
+                                "required": {"roles": ["user"]},
+                                "validations": {
+                                    "multivalued": {"min": 0, "max": 5},
+                                },
+                            },
                         ],
                         "groups": [
                             {
@@ -376,6 +450,31 @@ class TestKeycloakUserprofile(ModuleTestCase):
                                             "multivalued": False,
                                             "annotations": {},
                                         },
+                                        {
+                                            "annotations": {},
+                                            "displayName": "${testAttr}",
+                                            "multivalued": False,
+                                            "name": "testAttr",
+                                            "permissions": {"edit": ["admin", "user"], "view": ["admin", "user"]},
+                                            "required": {"roles": ["user"]},
+                                            "validations": {
+                                                "integer": {"min": 0, "max": 255},
+                                                "double": {},
+                                                "iso_date": {},
+                                                "local_date": {},
+                                            },
+                                        },
+                                        {
+                                            "annotations": {},
+                                            "displayName": "${testAttr2}",
+                                            "multivalued": True,
+                                            "name": "testAttr2",
+                                            "permissions": {"edit": ["admin", "user"], "view": ["admin", "user"]},
+                                            "required": {"roles": ["user"]},
+                                            "validations": {
+                                                "multivalued": {"min": 0, "max": 5},
+                                            },
+                                        },
                                     ],
                                     "groups": [
                                         {
@@ -528,6 +627,31 @@ class TestKeycloakUserprofile(ModuleTestCase):
                                             "multivalued": False,
                                             "annotations": {},
                                         },
+                                        {
+                                            "annotations": {},
+                                            "displayName": "${testAttr}",
+                                            "multivalued": False,
+                                            "name": "testAttr",
+                                            "permissions": {"edit": ["admin", "user"], "view": ["admin", "user"]},
+                                            "required": {"roles": ["user"]},
+                                            "validations": {
+                                                "integer": {"min": 0, "max": 255},
+                                                "double": {},
+                                                "iso_date": {},
+                                                "local_date": {},
+                                            },
+                                        },
+                                        {
+                                            "annotations": {},
+                                            "displayName": "${testAttr2}",
+                                            "multivalued": True,
+                                            "name": "testAttr2",
+                                            "permissions": {"edit": ["admin", "user"], "view": ["admin", "user"]},
+                                            "required": {"roles": ["user"]},
+                                            "validations": {
+                                                "multivalued": {"min": 0, "max": 5},
+                                            },
+                                        },
                                     ],
                                     "groups": [
                                         {
@@ -571,7 +695,3 @@ class TestKeycloakUserprofile(ModuleTestCase):
 
         # Verify that the module's changed status matches what is expected
         self.assertIs(exec_info.exception.args[0]["changed"], changed)
-
-
-if __name__ == "__main__":
-    unittest.main()
